/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __AIR_HOME_UTILS_H__
#define __AIR_HOME_UTILS_H__

#include <stdbool.h>
#include <Evas.h>

struct icon_info {
	const char *icon_file;
	const char *focus_icon_file;
	const char *photo_file;
	const char *focus_photo_file;
};

struct icon_info *utils_get_icon_info(void);
const char *utils_get_focus_photo_from_photo(const char *photo);
const char *utils_get_focus_icon_from_icon(const char *icon);
const char *utils_get_icon_from_photo(const char *photo);
const char *utils_get_photo_from_icon(const char *icon);

Evas_Object *utils_add_layout(Evas_Object *base, const char *group,
		bool focus_allow, const char *part);
Evas_Object *utils_add_icon(Evas_Object *base, const char *file,
		const char *part);
Evas_Object *utils_add_label(Evas_Object *base, char *text, const char *style,
		const char *part);
Evas_Object *utils_add_bg(Evas_Object *base, int r, int g, int b, int a,
		const char *part);
Evas_Object *utils_add_scroller(Evas_Object *base);
Evas_Object *utils_add_table(Evas_Object *base, bool homo, const char *part);
Evas_Object *utils_add_box(Evas_Object *base, bool horizon);
Evas_Object *utils_add_button(Evas_Object *base, char *text, const char *part);
Evas_Object *utils_add_entry(Evas_Object *base, char *text, bool password,
		const char *part);
Evas_Object *utils_add_popup(Evas_Object *base, char *title, char *message);
bool utils_launch_app(const char *pkg);

#endif /* __AIR_HOME_UTILS_H__ */
