/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <app_debug.h>
#include <Eina.h>
#include <media_content.h>

#include "data_photo.h"
#include "datamgr.h"

#define MEDIA_CONDITION_IMAGE "MEDIA_TYPE=0"

static bool _get_media(media_info_h m, void *data)
{
	int r;
	char *thumb;
	Eina_List **list;

	if (!m) {
		_ERR("Invalid argument");
		return false;
	}

	list = data;

	r = media_info_get_thumbnail_path(m, &thumb);
	if (r != MEDIA_CONTENT_ERROR_NONE || !thumb) {
		_ERR("failed to get thumb");
		return false;
	}

	*list = eina_list_append(*list, thumb);

	return true;
}

static void _unload_photo(struct datamgr *dm)
{
	char *thumb;

	EINA_LIST_FREE(dm->list, thumb)
		free(thumb);

	dm->list = NULL;
}

static Eina_List *_get_items(struct datamgr *dm)
{
	filter_h f;
	int r;

	if (!dm) {
		_ERR("Invalid argument");
		return NULL;
	}

	_unload_photo(dm);

	r = media_filter_create(&f);
	if (r != MEDIA_CONTENT_ERROR_NONE) {
		_ERR("failed to created filter");
		return NULL;
	}

	media_filter_set_condition(f, MEDIA_CONDITION_IMAGE,
			MEDIA_CONTENT_COLLATE_DEFAULT);

	r = media_info_foreach_media_from_db(f,
			_get_media, &dm->list);
	if (r != MEDIA_CONTENT_ERROR_NONE)
		_ERR("folder foreach failed");

	media_filter_destroy(f);


	return dm->list;
}

static bool _init(struct datamgr *dm)
{
	int r;

	if (!dm) {
		_ERR("Invalid argument");
		return false;
	}

	r = media_content_connect();
	if (r != MEDIA_CONTENT_ERROR_NONE) {
		_ERR("failed to connect media content");
		return false;
	}

	return true;
}

static void _fini(struct datamgr *dm)
{
	if (!dm) {
		_ERR("Invalid argument");
		return;
	}

	_unload_photo(dm);

	media_content_disconnect();
}

static struct data_class dclass = {
	.init = _init,
	.fini = _fini,
	.get_items = _get_items
};

struct data_class *datamgr_photo_get_dclass(void)
{
	return &dclass;
}
